# LinkMark


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**attrs** | [**Attrs**](Attrs.md) |  | [optional] 

## Example

```python
from src.client.generated.models.link_mark import LinkMark

# TODO update the JSON string below
json = "{}"
# create an instance of LinkMark from a JSON string
link_mark_instance = LinkMark.from_json(json)
# print the JSON string representation of the object
print(LinkMark.to_json())

# convert the object into a dict
link_mark_dict = link_mark_instance.to_dict()
# create an instance of LinkMark from a dict
link_mark_from_dict = LinkMark.from_dict(link_mark_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


